/* -*- c++ -*-
 *
 * systemtray.h
 *
 * Copyright (C) 2004, 2007 Sebastian Sauer <mail@dipe.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef __kmldonkey_systemtray_h__
#define __kmldonkey_systemtray_h__

#include <QToolTip>
#include <qwidget.h>
#include <ksystemtrayicon.h>

#include "kmldonkey.h"

class SystemTray : public KSystemTrayIcon
{
    Q_OBJECT

public:
    SystemTray(QWidget* parent);
    ~SystemTray();

    QString tooltip;

protected:
     bool event(QEvent *event);

#if 0
public Q_SLOTS:
    void dropEvent(QDropEvent* event);
    void dragEnterEvent(QDragEnterEvent* event);
#endif

};

#endif
